@@ -30,6 +30,9 @@
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(5, 1, 0)
 #include <drm/drm_crtc_helper.h>
+# if defined(RHEL_81)
+#  include <drm/drm_probe_helper.h>
+# endif
 #else
 #include <drm/drm_probe_helper.h>
 #endif
